WeztermPane

Struct WeztermPane 

pub struct WeztermPane {
Show 18 fields pub cursor_shape: String, pub cursor_visibility: String, pub cursor_x: i64, pub cursor_y: i64, pub cwd: PathBuf, pub is_active: bool, pub is_zoomed: bool, pub left_col: i64, pub pane_id: i64, pub size: WeztermPaneSize, pub tab_id: i64, pub tab_title: String, pub title: String, pub top_row: i64, pub tty_name: String, pub window_id: i64, pub window_title: String, pub workspace: String,
}
Represents a WezTerm pane with all its properties and state information.

Fields

cursor_shape: String

The shape of the cursor.

cursor_visibility: String

The visibility state of the cursor.

cursor_x: i64

The X coordinate of the cursor.

cursor_y: i64

The Y coordinate of the cursor.

cwd: PathBuf

The current working directory as a file URI.

is_active: bool

Whether this pane is currently active.

is_zoomed: bool

Whether this pane is zoomed (maximized).

left_col: i64

The left column position of the pane.

pane_id: i64

The unique ID of this pane.

size: WeztermPaneSize

The size dimensions of the pane.

tab_id: i64

The ID of the tab containing this pane.

tab_title: String

The title of the tab containing this pane.

title: String

The title of the pane.

top_row: i64

The top row position of the pane.

tty_name: String

The TTY device name associated with this pane.

window_id: i64

The ID of the window containing this pane.

window_title: String

The title of the window containing this pane.

workspace: String

The workspace name.

Implementations

Source

impl WeztermPane

pub fn is_sibling_terminal_pane_of(&self, other: &Self) -> bool

Given two WeztermPane checks if they are in the same tab and if the first has a current working directory that is the same or a child of the second one.

pub fn absolute_cwd(&self) -> PathBuf

Converts the current working directory from a file URI to an absolute PathBuf.